==> esp32c3-0.3.0.crate: esp32c3-0.3.0/src/timg0/wdtwprotect.rs <==
#[doc = "Register `WDTWPROTECT` reader"]
pub struct R(crate::R<WDTWPROTECT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WDTWPROTECT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<WDTWPROTECT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<WDTWPROTECT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `WDTWPROTECT` writer"]
pub struct W(crate::W<WDTWPROTECT_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<WDTWPROTECT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<WDTWPROTECT_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<WDTWPROTECT_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `WDT_WKEY` reader - reg_wdt_wkey."]
pub struct WDT_WKEY_R(crate::FieldReader<u32, u32>);
impl WDT_WKEY_R {
    pub(crate) fn new(bits: u32) -> Self {
        WDT_WKEY_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for WDT_WKEY_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `WDT_WKEY` writer - reg_wdt_wkey."]
pub struct WDT_WKEY_W<'a> {
    w: &'a mut W,
}
impl<'a> WDT_WKEY_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - reg_wdt_wkey."]
    #[inline(always)]
    pub fn wdt_wkey(&self) -> WDT_WKEY_R {
        WDT_WKEY_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - reg_wdt_wkey."]
    #[inline(always)]
    pub fn wdt_wkey(&mut self) -> WDT_WKEY_W {
        WDT_WKEY_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "TIMG_WDTWPROTECT_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdtwprotect](index.html) module"]
pub struct WDTWPROTECT_SPEC;
impl crate::RegisterSpec for WDTWPROTECT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wdtwprotect::R](R) reader structure"]
impl crate::Readable for WDTWPROTECT_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [wdtwprotect::W](W) writer structure"]
impl crate::Writable for WDTWPROTECT_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets WDTWPROTECT to value 0x50d8_3aa1"]
impl crate::Resettable for WDTWPROTECT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x50d8_3aa1
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/timg0/wdtwprotect.rs <==
#[doc = "Register `WDTWPROTECT` reader"]
pub struct R(crate::R<WDTWPROTECT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<WDTWPROTECT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<WDTWPROTECT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<WDTWPROTECT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `WDTWPROTECT` writer"]
pub struct W(crate::W<WDTWPROTECT_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<WDTWPROTECT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<WDTWPROTECT_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<WDTWPROTECT_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `WDT_WKEY` reader - reg_wdt_wkey."]
pub struct WDT_WKEY_R(crate::FieldReader<u32, u32>);
impl WDT_WKEY_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        WDT_WKEY_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for WDT_WKEY_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `WDT_WKEY` writer - reg_wdt_wkey."]
pub struct WDT_WKEY_W<'a> {
    w: &'a mut W,
}
impl<'a> WDT_WKEY_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - reg_wdt_wkey."]
    #[inline(always)]
    pub fn wdt_wkey(&self) -> WDT_WKEY_R {
        WDT_WKEY_R::new(self.bits)
    }
}
impl W {
    #[doc = "Bits 0:31 - reg_wdt_wkey."]
    #[inline(always)]
    pub fn wdt_wkey(&mut self) -> WDT_WKEY_W {
        WDT_WKEY_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "TIMG_WDTWPROTECT_REG.\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdtwprotect]
(index.html) module"]
pub struct WDTWPROTECT_SPEC;
impl crate::RegisterSpec for WDTWPROTECT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [wdtwprotect::R]
(R) reader structure"]
impl crate::Readable for WDTWPROTECT_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [wdtwprotect::W]
(W) writer structure"]
impl crate::Writable for WDTWPROTECT_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets WDTWPROTECT to value 0x50d8_3aa1"]
impl crate::Resettable for WDTWPROTECT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x50d8_3aa1
    }
}
